==> webkit2gtk_2.44.3.orig.tar.xz: webkitgtk-2.44.3/Source/JavaScriptCore/domjit/DOMJITCallDOMGetterSnippet.h <==
/*
 * Copyright (C) 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(JIT)

#include "DOMJITEffect.h"
#include "Snippet.h"

namespace JSC { namespace DOMJIT {

class CallDOMGetterSnippet : public Snippet {
public:
    static Ref<CallDOMGetterSnippet> create()
    {
        return adoptRef(*new CallDOMGetterSnippet());
    }

    // To look up DOMWrapper cache, GlobalObject is required.
    // FIXME: Later, we will extend this snippet to represent the result type by DOMJIT::Signature.
    // And after that, we will automatically pass a global object when the result type includes a DOM wrapper thing.
    // https://bugs.webkit.org/show_bug.cgi?id=162980
    bool requireGlobalObject { true };

    Effect effect { };

private:
    CallDOMGetterSnippet() = default;
};

} }

#endif

==> webkit2gtk_2.51.3.orig.tar.xz: webkitgtk-2.51.3/Source/JavaScriptCore/domjit/DOMJITCallDOMGetterSnippet.h <==
/*
 * Copyright (C) 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(JIT)

#include <JavaScriptCore/DOMJITEffect.h>
#include <JavaScriptCore/Snippet.h>

namespace JSC { namespace DOMJIT {

class CallDOMGetterSnippet : public Snippet {
public:
    static Ref<CallDOMGetterSnippet> create()
    {
        return adoptRef(*new CallDOMGetterSnippet());
    }

    // To look up DOMWrapper cache, GlobalObject is required.
    // FIXME: Later, we will extend this snippet to represent the result type by DOMJIT::Signature.
    // And after that, we will automatically pass a global object when the result type includes a DOM wrapper thing.
    // https://bugs.webkit.org/show_bug.cgi?id=162980
    bool requireGlobalObject { true };

    Effect effect { };

private:
    CallDOMGetterSnippet() = default;
};

} }

#endif
